@@ -1,5 +1,5 @@
 import typing
-from abc import ABC
+from abc import ABC, abstractmethod
 
 from openapi_builder.specification import Schema
 
@@ -20,5 +20,6 @@ class SchemaConverter(ABC):
         """Returns True if the Converter can match the specified class."""
         return isinstance(value, self.converts_class)
 
+    @abstractmethod
     def convert(self, value, name) -> Schema:
         raise NotImplementedError()
