@@ -10,6 +10,6 @@ def openapi_endpoint_name_from_rule(rule):
 
     for argument in rule.arguments:
         openapi_name = f"{{{argument}}}"
-        name = re.sub(fr"<[a-zA-Z:]*{argument}>", openapi_name, name)
+        name = re.sub(rf"<[a-zA-Z:]*{argument}>", openapi_name, name)
 
     return name
